@@ -1,5 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1">
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>AboutWindow</name>
     <message>
@@ -42,7 +43,7 @@ p, li { white-space: pre-wrap; }(new line)
         <source>A&amp;uthors</source>
         <translation>&amp;Udviklere</translation>
     </message>
-    <message encoding="UTF-8">
+    <message utf8="true">
         <location filename="../../src/ui/about.ui" line="157"/>
         <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
 p, li { white-space: pre-wrap; }
@@ -113,37 +114,37 @@ p, li { white-space: pre-wrap; }
 <context>
     <name>DataManager</name>
     <message>
-        <location filename="../../src/datamanager.cpp" line="83"/>
+        <location filename="../../src/datamanager.cpp" line="86"/>
         <source>Calculating</source>
         <translation>Beregner</translation>
     </message>
     <message>
-        <location filename="../../src/datamanager.cpp" line="245"/>
+        <location filename="../../src/datamanager.cpp" line="248"/>
         <source>Closing</source>
         <translation>Lukker</translation>
     </message>
     <message>
-        <location filename="../../src/datamanager.cpp" line="270"/>
+        <location filename="../../src/datamanager.cpp" line="273"/>
         <source>NEC files (*.nec)</source>
         <translation>NEC filer (*.nec)</translation>
     </message>
     <message>
-        <location filename="../../src/datamanager.cpp" line="270"/>
+        <location filename="../../src/datamanager.cpp" line="273"/>
         <source>All files (*.*)</source>
         <translation>Alle filer (*,*)</translation>
     </message>
     <message>
-        <location filename="../../src/datamanager.cpp" line="286"/>
+        <location filename="../../src/datamanager.cpp" line="292"/>
         <source>The file &quot;</source>
         <translation>filen &quot;</translation>
     </message>
     <message>
-        <location filename="../../src/datamanager.cpp" line="286"/>
+        <location filename="../../src/datamanager.cpp" line="292"/>
         <source>&quot; is already open.</source>
         <translation>&quot; er allerede ben.</translation>
     </message>
     <message>
-        <location filename="../../src/datamanager.cpp" line="307"/>
+        <location filename="../../src/datamanager.cpp" line="313"/>
         <source>Opening</source>
         <translation>Åbner</translation>
     </message>
@@ -194,6 +195,7 @@ p, li { white-space: pre-wrap; }
         <translation>nogle af antennerne, er nød til at blive beregnet</translation>
     </message>
     <message>
+        <location filename="../../src/ui/mainwindow.cpp" line="325"/>
         <location filename="../../src/ui/mainwindow.cpp" line="446"/>
         <source>Yes</source>
         <translation>Ja</translation>
@@ -244,7 +246,7 @@ p, li { white-space: pre-wrap; }
         <translation>Gem billede som</translation>
     </message>
     <message>
-        <location filename="../../src/ui/mainwindow.cpp" line="614"/>
+        <location filename="../../src/ui/mainwindow.cpp" line="613"/>
         <source>Rendering to &quot;&lt;font color=&quot;#000066&quot;&gt;</source>
         <translation>Gem som &quot;&lt;font color=&quot;#000066&quot;&gt;</translation>
     </message>
@@ -498,6 +500,7 @@ p, li { white-space: pre-wrap; }(new line)
         <translation>&amp;Gem til fil...</translation>
     </message>
     <message>
+        <location filename="../../src/ui/mainwindowqantenna.ui" line="998"/>
         <location filename="../../src/ui/mainwindowqantenna.ui" line="1001"/>
         <source>Render to file</source>
         <translation>Gem til fil</translation>
@@ -521,7 +524,7 @@ p, li { white-space: pre-wrap; }(new line)
 <context>
     <name>NECContainer</name>
     <message>
-        <location filename="../../src/neccontainer.cpp" line="226"/>
+        <location filename="../../src/neccontainer.cpp" line="225"/>
         <source>Rendering &quot;&lt;font color=&quot;#000066&quot;&gt;</source>
         <translation>Beregner &quot;&lt;font color=&quot;#000066&quot;&gt;</translation>
     </message>
@@ -529,12 +532,12 @@ p, li { white-space: pre-wrap; }(new line)
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../../src/main.cpp" line="68"/>
+        <location filename="../../src/main.cpp" line="66"/>
         <source>Checking if there is OpenGL support in this machine</source>
         <translation>Checker om der er OpenGL support på denne maskine</translation>
     </message>
     <message>
-        <location filename="../../src/main.cpp" line="79"/>
+        <location filename="../../src/main.cpp" line="77"/>
         <source>Loading QAntenna</source>
         <translation>Starter QAntenna</translation>
     </message>
@@ -542,17 +545,17 @@ p, li { white-space: pre-wrap; }(new line)
 <context>
     <name>QWidget</name>
     <message>
-        <location filename="../../src/main.cpp" line="71"/>
+        <location filename="../../src/main.cpp" line="69"/>
         <source>We don&apos;t have OpenGL support</source>
         <translation>Der er ikke OpenGL support</translation>
     </message>
     <message>
-        <location filename="../../src/main.cpp" line="74"/>
+        <location filename="../../src/main.cpp" line="71"/>
         <source>There is no OpenGL support in your system.&lt;br&gt;Closing QAntenna</source>
         <translation>Der er ingen OpenGL support i dit system.&lt;br&gt;Afslutter QAntenna</translation>
     </message>
     <message>
-        <location filename="../../src/necinput.cpp" line="139"/>
+        <location filename="../../src/necinput.cpp" line="137"/>
         <source>While trying to insert a FR card, I could not find a GE card in order to put the first card in a right place</source>
         <translation>Under forsøg på at indsætte FR kort, kunne der ikke findes et GE kort i den orden til at sætte det første kort på den rigtige plads</translation>
     </message>
@@ -562,16 +565,20 @@ p, li { white-space: pre-wrap; }(new line)
         <translation>Kunne ikke lava/åbne input.necin</translation>
     </message>
     <message>
+        <location filename="../../src/necinputparser.cpp" line="117"/>
         <location filename="../../src/necinputparser.cpp" line="205"/>
         <source>The following line can not be parsed properly</source>
         <translation>Den følgende linje kunne ikke parses korrekt</translation>
     </message>
     <message>
+        <location filename="../../src/necinputparser.cpp" line="119"/>
         <location filename="../../src/necinputparser.cpp" line="207"/>
         <source>The string list is</source>
         <translation>Strengen er</translation>
     </message>
     <message>
+        <location filename="../../src/necinputparser.cpp" line="226"/>
+        <location filename="../../src/necinputparser.cpp" line="234"/>
         <location filename="../../src/necinputparser.cpp" line="244"/>
         <source>QAntenna - NEC input parser</source>
         <translation>QAntenna - NEC input parser</translation>
