@@ -1,5 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="nl">
+<!DOCTYPE TS>
+<TS version="2.0" language="nl">
 <context>
     <name>AboutWindow</name>
     <message>
@@ -17,7 +18,7 @@
         <source>A&amp;uthors</source>
         <translation>A&amp;uteurs</translation>
     </message>
-    <message encoding="UTF-8">
+    <message utf8="true">
         <location filename="../../src/ui/about.ui" line="157"/>
         <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
 p, li { white-space: pre-wrap; }
@@ -148,37 +149,37 @@ p, li { white-space: pre-wrap; }
 <context>
     <name>DataManager</name>
     <message>
-        <location filename="../../src/datamanager.cpp" line="245"/>
+        <location filename="../../src/datamanager.cpp" line="248"/>
         <source>Closing</source>
         <translation>Sluiten</translation>
     </message>
     <message>
-        <location filename="../../src/datamanager.cpp" line="270"/>
+        <location filename="../../src/datamanager.cpp" line="273"/>
         <source>NEC files (*.nec)</source>
         <translation>NEC bestanden (*.nec)</translation>
     </message>
     <message>
-        <location filename="../../src/datamanager.cpp" line="270"/>
+        <location filename="../../src/datamanager.cpp" line="273"/>
         <source>All files (*.*)</source>
         <translation>Alle bestanden (*.*)</translation>
     </message>
     <message>
-        <location filename="../../src/datamanager.cpp" line="286"/>
+        <location filename="../../src/datamanager.cpp" line="292"/>
         <source>The file &quot;</source>
         <translation>Het bestand &quot;</translation>
     </message>
     <message>
-        <location filename="../../src/datamanager.cpp" line="286"/>
+        <location filename="../../src/datamanager.cpp" line="292"/>
         <source>&quot; is already open.</source>
         <translation>&quot; is al geopend.</translation>
     </message>
     <message>
-        <location filename="../../src/datamanager.cpp" line="307"/>
+        <location filename="../../src/datamanager.cpp" line="313"/>
         <source>Opening</source>
         <translation>Openen</translation>
     </message>
     <message>
-        <location filename="../../src/datamanager.cpp" line="83"/>
+        <location filename="../../src/datamanager.cpp" line="86"/>
         <source>Calculating</source>
         <translation>Berekenen</translation>
     </message>
@@ -214,6 +215,7 @@ p, li { white-space: pre-wrap; }
         <translation>Welkom bij</translation>
     </message>
     <message>
+        <location filename="../../src/ui/mainwindow.cpp" line="325"/>
         <location filename="../../src/ui/mainwindow.cpp" line="446"/>
         <source>Yes</source>
         <translation>Ja</translation>
@@ -264,7 +266,7 @@ p, li { white-space: pre-wrap; }
         <translation>Sla beeld op Als</translation>
     </message>
     <message>
-        <location filename="../../src/ui/mainwindow.cpp" line="614"/>
+        <location filename="../../src/ui/mainwindow.cpp" line="613"/>
         <source>Rendering to &quot;&lt;font color=&quot;#000066&quot;&gt;</source>
         <translation>Berekenen naar &quot;&lt;font color=&quot;#000066&quot;&gt;</translation>
     </message>
@@ -462,6 +464,7 @@ p, li { white-space: pre-wrap; }
         <translation>Ctrl+A</translation>
     </message>
     <message>
+        <location filename="../../src/ui/mainwindowqantenna.ui" line="998"/>
         <location filename="../../src/ui/mainwindowqantenna.ui" line="1001"/>
         <source>Render to file</source>
         <translation>Bereken naar bestand</translation>
@@ -556,7 +559,7 @@ p, li { white-space: pre-wrap; }
 <context>
     <name>NECContainer</name>
     <message>
-        <location filename="../../src/neccontainer.cpp" line="226"/>
+        <location filename="../../src/neccontainer.cpp" line="225"/>
         <source>Rendering &quot;&lt;font color=&quot;#000066&quot;&gt;</source>
         <translation>Berekenen &quot;&lt;font color=&quot;#000066&quot;&gt;</translation>
     </message>
@@ -564,12 +567,12 @@ p, li { white-space: pre-wrap; }
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../../src/main.cpp" line="79"/>
+        <location filename="../../src/main.cpp" line="77"/>
         <source>Loading QAntenna</source>
         <translation>Laden van QAntenna</translation>
     </message>
     <message>
-        <location filename="../../src/main.cpp" line="68"/>
+        <location filename="../../src/main.cpp" line="66"/>
         <source>Checking if there is OpenGL support in this machine</source>
         <translation>Controle of OpenGL wordt ondersteund op deze machine</translation>
     </message>
@@ -577,7 +580,7 @@ p, li { white-space: pre-wrap; }
 <context>
     <name>QWidget</name>
     <message>
-        <location filename="../../src/necinput.cpp" line="139"/>
+        <location filename="../../src/necinput.cpp" line="137"/>
         <source>While trying to insert a FR card, I could not find a GE card in order to put the first card in a right place</source>
         <translation>Er werd geen GE kaart gevonden terwijl een FR kaart werd ingevoegd</translation>
     </message>
@@ -587,16 +590,20 @@ p, li { white-space: pre-wrap; }
         <translation>input.necin kan niet worden aangemaakt/gelezen</translation>
     </message>
     <message>
+        <location filename="../../src/necinputparser.cpp" line="117"/>
         <location filename="../../src/necinputparser.cpp" line="205"/>
         <source>The following line can not be parsed properly</source>
         <translation>De volgende regel kan niet correct worden gelezen</translation>
     </message>
     <message>
+        <location filename="../../src/necinputparser.cpp" line="119"/>
         <location filename="../../src/necinputparser.cpp" line="207"/>
         <source>The string list is</source>
         <translation>De string lijst is</translation>
     </message>
     <message>
+        <location filename="../../src/necinputparser.cpp" line="226"/>
+        <location filename="../../src/necinputparser.cpp" line="234"/>
         <location filename="../../src/necinputparser.cpp" line="244"/>
         <source>QAntenna - NEC input parser</source>
         <translation>QAntenna - pogramma voor het lezen van NEC bestanden</translation>
@@ -617,12 +624,12 @@ p, li { white-space: pre-wrap; }
         <translation>Het bestans is leeg</translation>
     </message>
     <message>
-        <location filename="../../src/main.cpp" line="71"/>
+        <location filename="../../src/main.cpp" line="69"/>
         <source>We don&apos;t have OpenGL support</source>
         <translation>Er is geen OpenGL ondersteuning</translation>
     </message>
     <message>
-        <location filename="../../src/main.cpp" line="74"/>
+        <location filename="../../src/main.cpp" line="71"/>
         <source>There is no OpenGL support in your system.&lt;br&gt;Closing QAntenna</source>
         <translation>Er is geen OpenGL ondersteuning op uw systeem.&lt;br&gt;QAntenna wordt afgesloten</translation>
     </message>
