@@ -1,5 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1">
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>AboutWindow</name>
     <message>
@@ -17,7 +18,7 @@
         <source>A&amp;uthors</source>
         <translation>&amp;Авторы</translation>
     </message>
-    <message encoding="UTF-8">
+    <message utf8="true">
         <location filename="../../src/ui/about.ui" line="157"/>
         <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
 p, li { white-space: pre-wrap; }
@@ -105,37 +106,37 @@ p, li { white-space: pre-wrap; }
 <context>
     <name>DataManager</name>
     <message>
-        <location filename="../../src/datamanager.cpp" line="245"/>
+        <location filename="../../src/datamanager.cpp" line="248"/>
         <source>Closing</source>
         <translation>Закрытие</translation>
     </message>
     <message>
-        <location filename="../../src/datamanager.cpp" line="270"/>
+        <location filename="../../src/datamanager.cpp" line="273"/>
         <source>NEC files (*.nec)</source>
         <translation>Файлы NEC (*.nec)</translation>
     </message>
     <message>
-        <location filename="../../src/datamanager.cpp" line="270"/>
+        <location filename="../../src/datamanager.cpp" line="273"/>
         <source>All files (*.*)</source>
         <translation>Все файлы (*.*)</translation>
     </message>
     <message>
-        <location filename="../../src/datamanager.cpp" line="286"/>
+        <location filename="../../src/datamanager.cpp" line="292"/>
         <source>The file &quot;</source>
         <translation>Файл &quot;</translation>
     </message>
     <message>
-        <location filename="../../src/datamanager.cpp" line="286"/>
+        <location filename="../../src/datamanager.cpp" line="292"/>
         <source>&quot; is already open.</source>
         <translation>&quot; уже открыт.</translation>
     </message>
     <message>
-        <location filename="../../src/datamanager.cpp" line="307"/>
+        <location filename="../../src/datamanager.cpp" line="313"/>
         <source>Opening</source>
         <translation>Открытие</translation>
     </message>
     <message>
-        <location filename="../../src/datamanager.cpp" line="83"/>
+        <location filename="../../src/datamanager.cpp" line="86"/>
         <source>Calculating</source>
         <translation>Расчет</translation>
     </message>
@@ -171,6 +172,7 @@ p, li { white-space: pre-wrap; }
         <translation>Добро пожаловать в</translation>
     </message>
     <message>
+        <location filename="../../src/ui/mainwindow.cpp" line="325"/>
         <location filename="../../src/ui/mainwindow.cpp" line="446"/>
         <source>Yes</source>
         <translation>Да</translation>
@@ -221,7 +223,7 @@ p, li { white-space: pre-wrap; }
         <translation>Сохранить изображение как</translation>
     </message>
     <message>
-        <location filename="../../src/ui/mainwindow.cpp" line="614"/>
+        <location filename="../../src/ui/mainwindow.cpp" line="613"/>
         <source>Rendering to &quot;&lt;font color=&quot;#000066&quot;&gt;</source>
         <translation>Формирование изображения в  &quot;&lt;font color=&quot;#000066&quot;&gt;</translation>
     </message>
@@ -424,6 +426,7 @@ p, li { white-space: pre-wrap; }
         <translation>&amp;Формировать изображение в файл...</translation>
     </message>
     <message>
+        <location filename="../../src/ui/mainwindowqantenna.ui" line="998"/>
         <location filename="../../src/ui/mainwindowqantenna.ui" line="1001"/>
         <source>Render to file</source>
         <translation>Формировать изображение в файл</translation>
@@ -513,7 +516,7 @@ p, li { white-space: pre-wrap; }
 <context>
     <name>NECContainer</name>
     <message>
-        <location filename="../../src/neccontainer.cpp" line="226"/>
+        <location filename="../../src/neccontainer.cpp" line="225"/>
         <source>Rendering &quot;&lt;font color=&quot;#000066&quot;&gt;</source>
         <translation>Формирование изображения &quot;&lt;font color=&quot;#000066&quot;&gt;</translation>
     </message>
@@ -521,12 +524,12 @@ p, li { white-space: pre-wrap; }
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../../src/main.cpp" line="68"/>
+        <location filename="../../src/main.cpp" line="66"/>
         <source>Checking if there is OpenGL support in this machine</source>
         <translation>Проверка, поддерживается ли OpenGL на этом компьютере</translation>
     </message>
     <message>
-        <location filename="../../src/main.cpp" line="79"/>
+        <location filename="../../src/main.cpp" line="77"/>
         <source>Loading QAntenna</source>
         <translation>Загрузка QAntenna</translation>
     </message>
@@ -534,17 +537,17 @@ p, li { white-space: pre-wrap; }
 <context>
     <name>QWidget</name>
     <message>
-        <location filename="../../src/main.cpp" line="71"/>
+        <location filename="../../src/main.cpp" line="69"/>
         <source>We don&apos;t have OpenGL support</source>
         <translation>Нет поддержки OpenGL</translation>
     </message>
     <message>
-        <location filename="../../src/main.cpp" line="74"/>
+        <location filename="../../src/main.cpp" line="71"/>
         <source>There is no OpenGL support in your system.&lt;br&gt;Closing QAntenna</source>
         <translation>Ваша система не поддерживает OpenGL.&lt;br&gt;QAntenna будет закрыта</translation>
     </message>
     <message>
-        <location filename="../../src/necinput.cpp" line="139"/>
+        <location filename="../../src/necinput.cpp" line="137"/>
         <source>While trying to insert a FR card, I could not find a GE card in order to put the first card in a right place</source>
         <translation>При попытке вставки карты FR, не могу найти карту GE для правильного размещения первой карты</translation>
     </message>
@@ -554,16 +557,20 @@ p, li { white-space: pre-wrap; }
         <translation>Не могу создать/открыть input.necin</translation>
     </message>
     <message>
+        <location filename="../../src/necinputparser.cpp" line="117"/>
         <location filename="../../src/necinputparser.cpp" line="205"/>
         <source>The following line can not be parsed properly</source>
         <translation>Эта строка не может быть правильно распознана</translation>
     </message>
     <message>
+        <location filename="../../src/necinputparser.cpp" line="119"/>
         <location filename="../../src/necinputparser.cpp" line="207"/>
         <source>The string list is</source>
         <translation>Список строк</translation>
     </message>
     <message>
+        <location filename="../../src/necinputparser.cpp" line="226"/>
+        <location filename="../../src/necinputparser.cpp" line="234"/>
         <location filename="../../src/necinputparser.cpp" line="244"/>
         <source>QAntenna - NEC input parser</source>
         <translation>QAntenna - распознавание данных NEC</translation>
